@@ -6,7 +6,6 @@ test_that("data", {
   expect_r6(b, "DataBackendDplyr")
   expect_backend(b)
   expect_iris_backend(b)
-  disconnect(b)
 })
 
 test_that("DataBackend", {
@@ -14,7 +13,6 @@ test_that("DataBackend", {
   expect_r6(b, "DataBackendDplyr")
   expect_iris_backend(b)
   expect_backend(b)
-  disconnect(b)
 })
 
 test_that("Task", {
@@ -23,12 +21,10 @@ test_that("Task", {
   expect_r6(task$backend, "DataBackendDplyr")
   expect_backend(task$backend)
   expect_task(task)
-  disconnect(task$backend)
 })
 
 test_that("connector is automatically set", {
   b = as_sqlite_backend(iris, path = tempfile())
   expect_function(b$connector)
   expect_set_equal(ls(environment(b$connector), all.names = TRUE), "path")
-  disconnect(b)
 })
