@@ -10,29 +10,28 @@ test_that("expectations + dplyr", {
   skip_if_not_installed("dbplyr")
 
   b1 = as_sqlite_backend(iris, path = tempfile())
-  on.exit(disconnect(b1))
+  on.exit(disconnect(b1), add = TRUE)
 
   b2 = roundtrip(b1)
-  expect_false(b2$valid)
+  on.exit(disconnect(b2), add = TRUE)
 
+  expect_false(b2$valid)
   expect_backend(b2)
   expect_iris_backend(b2)
-  disconnect(b1)
-  disconnect(b2)
 })
 
 
 test_that("expectations + duckdb", {
-  skip_if_not_installed("duckdb")
+  skip_if_not_installed("duckdb", "0.2.6")
 
   b1 = as_duckdb_backend(iris, path = tempfile())
-  b2 = roundtrip(b)
-  expect_false(b2$valid)
+  on.exit(disconnect(b1), add = TRUE)
+  b2 = roundtrip(b1)
+  on.exit(disconnect(b2), add = TRUE)
 
+  expect_false(b2$valid)
   expect_backend(b2)
   expect_iris_backend(b2)
-  disconnect(b1)
-  disconnect(b2)
 })
 
 test_that("filtered tbl", {
@@ -45,28 +44,24 @@ test_that("filtered tbl", {
 
   keep = c("row_id", "Sepal.Length", "Petal.Length", "Species")
   con = DBI::dbConnect(RSQLite::SQLite(), path)
+  on.exit(disconnect(con), add = TRUE)
+
   tbl = dplyr::tbl(con, "data")
   tbl = dplyr::select_at(tbl, keep)
   tbl = dplyr::filter(tbl, Species == "setosa")
   expect_data_frame(dplyr::collect(tbl), nrows = 50, ncols = 4)
 
   b = DataBackendDplyr$new(tbl, "row_id")
+  # on.exit(disconnect(b), add = TRUE)
+
   expect_equal(b$ncol, 4)
   expect_equal(b$nrow, 50)
   expect_set_equal(b$colnames, keep)
 
   b$connector = sqlite_reconnector(path)
-  roundtrip = function(x) {
-    path = tempfile()
-    on.exit(file.remove(path))
-    saveRDS(x, path)
-    readRDS(path)
-  }
   b = roundtrip(b)
 
   expect_equal(b$nrow, 50)
   expect_equal(b$ncol, 4)
   expect_set_equal(b$colnames, keep)
-
-  disconnect(b)
 })
